//
//  DBusItemSource.cs
//  
//  Author:
//       Alex Launi <alex.launi@gmail.com>
// 
//  Copyright (c) 2010 Do developers
// 
//  This program is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  (at your option) any later version.
// 
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
// 
//  You should have received a copy of the GNU General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.

using System;
using System.Collections.Generic;
using System.Linq;

using NDesk.DBus;

using Do.Universe;

namespace Do.DBus
{
	internal delegate void DBusItemsAddedHandler (ObjectPath [] objectPaths);
	internal delegate void DBusItemsRemovedHandler (ObjectPath [] objectPaths);

	[Interface ("org.gnome.Do.ItemSource")]
	internal interface IDBusItemSource
	{
		event DBusItemsAddedHandler ItemsAdded;
		event DBusItemsRemovedHandler ItemsRemoved;

		ObjectPath [] Items { get; }
		ObjectPath [] ChildrenOfItem (ObjectPath itemPath);
	}

	internal class DBusItemSource : DBusObject, IItemSource
	{
		IDBusItem inner_item;
		IDBusItemSource inner_source;

		internal DBusItemSource (ObjectPath path, IDBusItem innerItem, IDBusItemSource innerSource)
			: base (path)
		{
			inner_item = innerItem;
			inner_source = innerSource;
		}

#region IItemSource implementation
		public event ItemsAddedHandler ItemsAdded;
		public event ItemsRemovedHandler ItemsRemoved;

		public IEnumerable<IItem> ChildrenOfItem (IItem item)
		{
			throw new NotImplementedException ();
		}

		public IEnumerable<IItem> Items {
			get {
				throw new NotImplementedException ();
			}
		}
#endregion

#region IItem implementation
		public string Name {
			get {
				return inner_item.Name;
			}
		}

		public string Description {
			get {
				return inner_item.Description;
			}
		}

		public string Icon {
			get {
				return inner_item.Icon;
			}
		}
#endregion
	}
}


